@@ -6,36 +6,43 @@
 #![warn(missing_docs)]
 // FIXME: Remove once lint doesn't trigger on std::convert::TryFrom in macros.rs anymore
 #![allow(unused_qualifications)]
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 
-// Renamed in `Cargo.toml` so we can have a serde feature.
-// Rename it back here because `serde1` is ugly.
+// Renamed in `Cargo.toml` so we can features with the same name as the package.
+// Rename them back here because the `Cargo.toml` names are ugly.
 #[cfg(feature = "serde")]
 extern crate serde1 as serde;
 
+#[cfg(feature = "rand")]
+extern crate rand_crate as rand;
+
 #[cfg(feature = "serde")]
 use std::convert::TryFrom;
+use std::fmt;
 
 #[cfg(feature = "serde")]
 use serde::de::{self, Deserializer, Unexpected};
 
 #[doc(inline)]
 pub use crate::{
-    client_secret::{ClientSecret, ClientSecretBox},
+    client_secret::ClientSecret,
     crypto_algorithms::{DeviceKeyAlgorithm, EventEncryptionAlgorithm, SigningKeyAlgorithm},
+    device_id::DeviceId,
     device_key_id::DeviceKeyId,
     event_id::EventId,
     key_id::{DeviceSigningKeyId, KeyId, ServerSigningKeyId, SigningKeyId},
+    key_name::KeyName,
+    matrix_uri::MatrixToUri,
     mxc_uri::MxcUri,
-    opaque_ids::{DeviceId, DeviceIdBox, KeyName, KeyNameBox},
     room_alias_id::RoomAliasId,
     room_id::RoomId,
-    room_id_or_room_alias_id::RoomIdOrAliasId,
-    room_name::{RoomName, RoomNameBox},
+    room_name::RoomName,
+    room_or_room_alias_id::RoomOrAliasId,
     room_version_id::RoomVersionId,
-    server_name::{ServerName, ServerNameBox},
-    session_id::{SessionId, SessionIdBox},
+    server_name::ServerName,
+    session_id::SessionId,
     signatures::{DeviceSignatures, EntitySignatures, ServerSignatures, Signatures},
+    transaction_id::TransactionId,
     user_id::UserId,
 };
 #[doc(inline)]
@@ -44,23 +51,26 @@ pub use ruma_identifiers_validation::error::Error;
 #[macro_use]
 mod macros;
 
+pub mod matrix_uri;
 pub mod user_id;
 
 mod client_secret;
 mod crypto_algorithms;
+mod device_id;
 mod device_key_id;
 mod event_id;
 mod key_id;
+mod key_name;
 mod mxc_uri;
-mod opaque_ids;
 mod room_alias_id;
 mod room_id;
-mod room_id_or_room_alias_id;
 mod room_name;
+mod room_or_room_alias_id;
 mod room_version_id;
 mod server_name;
 mod session_id;
 mod signatures;
+mod transaction_id;
 
 /// Generates a random identifier localpart.
 #[cfg(feature = "rand")]
@@ -88,11 +98,11 @@ where
     })
 }
 
-/// Shorthand for `Box::<DeviceId>::from`.
+/// Shorthand for `<&DeviceId>::from`.
 #[macro_export]
 macro_rules! device_id {
-    ($s:tt) => {
-        ::std::boxed::Box::<$crate::DeviceId>::from($s)
+    ($s:expr) => {
+        <&$crate::DeviceId as ::std::convert::From<_>>::from($s)
     };
 }
 
@@ -174,3 +184,16 @@ macro_rules! user_id {
         $crate::_macros::user_id!($crate, $s)
     };
 }
+
+// Wrapper around `Box<str>` that cannot be used in a meaningful way outside of
+// this crate. Used for string enums because their `_Custom` variant can't be
+// truly private (only `#[doc(hidden)]`).
+#[doc(hidden)]
+#[derive(Clone, PartialEq, Eq, PartialOrd, Ord)]
+pub struct PrivOwnedStr(Box<str>);
+
+impl fmt::Debug for PrivOwnedStr {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        self.0.fmt(f)
+    }
+}
